#!perl

BEGIN {
  unless ($ENV{RELEASE_TESTING}) {
    print qq{1..0 # SKIP these tests are for release candidate testing\n};
    exit
  }
}


# This file was automatically generated by Dist::Zilla::Plugin::Regexp::Pattern.

use Test::More;

eval "use Test::Regexp::Pattern 0.001";
plan skip_all => "Test::Regexp::Pattern 0.001+ required for testing regexp patterns"
  if $@;

regexp_patterns_in_all_modules_ok();
